Module types

Module types 

Core types and structs used throughout the library including OutputGroup and CoinSelectionOpt

Structs

CoinSelectionOpt
Options required to compute fees and waste metric.
OutputGroup
Represents an input candidate for Coinselection, either as a single UTXO or a group of UTXOs.
SelectionOutput
The result of selection algorithm.
WasteMetric
Measures the efficiency of input selection in satoshis, helping evaluate algorithms based on current and long-term fee rates

Enums

ExcessStrategy
Strategy to decide what to do with the excess amount.
SelectionAlgorithm
Identifies which selection algorithm produced a given SelectionOutput.
SelectionError
Error Describing failure of a selection attempt, on any subset of inputs.

Constants

TOTAL_TRIES
Upper bound on explored nodes,the bounded-search policy used by BnB and Coingrinder.

Type Aliases

EffectiveValue
EffectiveValue type alias
Weight
Weight type alias