pub enum SelectionError {
InsufficientFunds {
available: u64,
required: u64,
},
NoSolutionFound,
NonPositiveTarget,
NonPositiveFeeRate,
AbnormallyHighFeeRate,
}Expand description
Error Describing failure of a selection attempt, on any subset of inputs.
Variants
InsufficientFunds
The available UTXOs cannot cover the target and fees for spending the supplied inputs.
NoSolutionFound
NonPositiveTarget
NonPositiveFeeRate
AbnormallyHighFeeRate