pub struct WasteMetric(pub i64);Expand description
Measures the efficiency of input selection in satoshis, helping evaluate algorithms based on current and long-term fee rates
WasteMetric strikes a balance between minimizing current transaction fees and overall fees during the wallet’s lifetime. In high fee rate environments, selecting fewer inputs reduces transaction fees. In low fee rate environments, selecting more inputs reduces overall fees. It compares various selection algorithms to find the most optimized solution, represented by the lowest WasteMetric value.
Tuple Fields
0: i64Trait Implementations
Sourceimpl Clone for WasteMetric
impl Clone for WasteMetric
Sourcefn clone(&self) -> WasteMetric
fn clone(&self) -> WasteMetric
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for WasteMetric
Sourceimpl Debug for WasteMetric
impl Debug for WasteMetric
impl Eq for WasteMetric
Sourceimpl Ord for WasteMetric
impl Ord for WasteMetric
Sourcefn cmp(&self, other: &WasteMetric) -> Ordering
fn cmp(&self, other: &WasteMetric) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for WasteMetric
impl PartialEq for WasteMetric
Sourcefn eq(&self, other: &WasteMetric) -> bool
fn eq(&self, other: &WasteMetric) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WasteMetric
impl PartialOrd for WasteMetric
impl StructuralPartialEq for WasteMetric