Module utils

Module utils 

Helper functions with tests for fee calculation, weight computation, and waste metrics

Functions

calculate_accumulated_weight
adjusted_target is the target value plus the estimated fee.
calculate_fee
calculate_fee_and_waste
Computes the total fee and waste metric (in satoshis) for a selection.